import { useEffect } from 'react';
import { useLocation } from 'react-router-dom';
import { openFromOtherPage } from './openFromOtherpAge';

export const openTab = (tabId: string) => {
  // Hide all tabs
  const tabs = document.querySelectorAll('.tabcontent');
  tabs.forEach((tab) => {
    (tab as HTMLElement).style.display = 'none';
  });

  // Show the selected tab
  const selectedTab = document.getElementById(tabId);
  if (selectedTab) {
    selectedTab.style.display = 'block';
  }
};

export const openNestedTab = (parentTabId: string, childTabId: string) => {
  // Open parent tab
  openTab(parentTabId);

  // Open child tab inside parent tab
  const nestedTabs = document.querySelectorAll(`#${parentTabId} .nested-tabcontent`);
  nestedTabs.forEach((tab) => {
    (tab as HTMLElement).style.display = 'none';
  });

  const selectedNestedTab = document.getElementById(childTabId);
  if (selectedNestedTab) {
    selectedNestedTab.style.display = 'block';
  }
};

export const handleScrollToCollapse = (collapseId: string) => {
  const collapseElement = document.getElementById(collapseId);
  if (collapseElement) {
    const elementTop = collapseElement.getBoundingClientRect().top + window.pageYOffset;
    const offset = window.innerHeight / 2 - collapseElement.offsetHeight / 2;
    const scrollPosition = elementTop - offset;

    window.scrollTo({
      top: scrollPosition,
      behavior: 'smooth',
    });
  }
};

export const TabNavigation = () => {
  const location = useLocation();

  useEffect(() => {
    const params = new URLSearchParams(location.search);
    const collapseId = params.get('collapseId');
    const tabId = params.get('tab');
    const subTabId = params.get('subTab'); // Neues Parameter für verschachtelte Tabs

    // Open the tab specified by tabId (and subTab if nested)
    if (tabId) {
      if (subTabId) {
        // If subTab is provided, open the nested tab
        openNestedTab(tabId, subTabId);
      } else {
        // Otherwise, just open the main tab
        openTab(tabId);
      }
    }

    // Scroll to the section specified by collapseId after opening the tab
    if (collapseId) {
      handleScrollToCollapse(collapseId);
    }

    // Open the tab from another page
    if (tabId) {
      openFromOtherPage(tabId)({ currentTarget: document.getElementById(tabId)! });
    }
  }, [location.search]);

  return 
};

export default TabNavigation;
